@@ -13,16 +13,13 @@ General conventions:
 * Unless explictly specified otherwise, all sorting is in ascending order.
 * Unless explictly specified otherwise, elements with zero quantity, rolls, etc.
     are considered.
-* The words "min" and "max" refer to outcomes, and the words "low" and "high"
-refer to dice in a pool.
 """
 
 __docformat__ = 'google'
 
 from typing import Final
 
-from icepool.constant import Order, RerollType
-from icepool.typing import Outcome
+from icepool.typing import Outcome, Order, RerollType
 
 Reroll: Final = RerollType.Reroll
 """Indicates that an outcome should be rerolled (with unlimited depth).
@@ -47,8 +44,8 @@ Operation in specific cases:
 
 # Expose certain names at top-level.
 
-from icepool.population.func import (standard, d, __getattr__, bernoulli, coin,
-                                     one_hot, cartesian_product,
+from icepool.population.func import (d, __getattr__, coin, one_hot,
+                                     cartesian_product,
                                      from_cumulative_quantities, from_rv,
                                      min_outcome, max_outcome, align,
                                      align_range, reduce, accumulate, apply,
@@ -63,30 +60,23 @@ from icepool.counts import CountsKeysView, CountsValuesView, CountsItemsView
 
 from icepool.population.lowest_highest import lowest, highest, sum_lowest, sum_highest
 
-from icepool.generator.pool import Pool, standard_pool, clear_pool_cache
-from icepool.generator.outcome_count_generator import OutcomeCountGenerator, NextOutcomeCountGenerator
+from icepool.generator.pool import Pool, standard_pool
+from icepool.generator.outcome_count_generator import OutcomeCountGenerator, NextOutcomeCountGenerator, implicit_convert_to_generator
 from icepool.evaluator.outcome_count_evaluator import OutcomeCountEvaluator
-from icepool.evaluator.evaluators import (
-    WrapFuncEvaluator, JointEvaluator, SumEvaluator, sum_evaluator,
-    ExpandEvaluator, expand_evaluator, CountInEvaluator, count_unique_evaluator,
-    SubsetTargetEvaluator, ContainsSubsetEvaluator, IntersectionSizeEvaluator,
-    LargestMatchingSetEvaluator, LargestMatchingSetAndOutcomeEvaluator,
-    AllMatchingSetsEvaluator, LargestStraightEvaluator,
-    LargestStraightAndOutcomeEvaluator)
 
 from icepool.population.deck import Deck
 from icepool.generator.deal import Deal
 
-from icepool.generator.generators import SuitGenerator
+from icepool.generator.suit import SuitGenerator
+
+import icepool.evaluator as evaluator
 
 __all__ = [
-    'standard', 'd', 'bernoulli', 'coin', 'one_hot', 'cartesian_product',
-    'Outcome', 'Die', 'Population', 'Again', 'CountsKeysView',
-    'CountsValuesView', 'CountsItemsView', 'from_cumulative_quantities',
-    'from_rv', 'align', 'align_range', 'lowest', 'highest', 'sum_lowest',
-    'sum_highest', 'min_outcome', 'max_outcome', 'reduce', 'accumulate',
-    'apply', 'apply_sorted', 'Reroll', 'RerollType', 'OutcomeCountGenerator',
-    'Pool', 'standard_pool', 'OutcomeCountEvaluator', 'Order', 'JointEvaluator',
-    'SumEvaluator', 'ExpandEvaluator', 'Deck', 'Deal', 'SuitGenerator',
-    'clear_pool_cache'
+    'd', 'coin', 'one_hot', 'cartesian_product', 'Outcome', 'Die', 'Population',
+    'Again', 'CountsKeysView', 'CountsValuesView', 'CountsItemsView',
+    'from_cumulative_quantities', 'from_rv', 'align', 'align_range', 'lowest',
+    'highest', 'sum_lowest', 'sum_highest', 'min_outcome', 'max_outcome',
+    'reduce', 'accumulate', 'apply', 'apply_sorted', 'Reroll', 'RerollType',
+    'OutcomeCountGenerator', 'Pool', 'standard_pool', 'OutcomeCountEvaluator',
+    'Order', 'evaluator', 'Deck', 'Deal', 'SuitGenerator'
 ]
