@@ -2,8 +2,7 @@ __docformat__ = 'google'
 
 import icepool
 from icepool.generator.alignment import Alignment
-from icepool.constant import Order
-from icepool.typing import Outcome
+from icepool.typing import Outcome, Order
 
 from abc import ABC, abstractmethod
 from collections import defaultdict
@@ -23,8 +22,13 @@ T_contra = TypeVar('T_contra', bound=Outcome, contravariant=True)
 U_co = TypeVar('U_co', bound=Outcome, covariant=True)
 """Type variable representing the final outcome type."""
 
+Q_contra = TypeVar('Q_contra', contravariant=True)
+"""Type variable representing the type of individual counts.
 
-class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
+This may be replaced with a `TypeVarTuple` in the future."""
+
+
+class OutcomeCountEvaluator(ABC, Generic[T_contra, Q_contra, U_co]):
     """An abstract, immutable, callable class for evaulating one or more `OutcomeCountGenerator`s.
 
     There is one abstract method to implement: `next_state()`.
@@ -58,7 +62,7 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
 
     @abstractmethod
     def next_state(self, state: Hashable, outcome: T_contra, /,
-                   *counts) -> Hashable:
+                   *counts: Q_contra) -> Hashable:
         """State transition function.
 
         This should produce a state given the previous state, an outcome,
@@ -107,7 +111,7 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
 
     def final_outcome(
             self, final_state: Hashable, /,
-            *generators: icepool.OutcomeCountGenerator[T_contra]) -> U_co:
+            *generators: icepool.OutcomeCountGenerator[T_contra, Any]) -> U_co:
         """Optional function to generate a final outcome from a final state.
 
         Tthere is no expectation that a subclass be able to handle
@@ -117,7 +121,8 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
 
         By default, the final outcome is equal to the final state.
         Note that `None` is not a valid outcome for a `Die`,
-        and if there are no outcomes, the final state will be `None`.
+        and if there are no outcomes, `final_outcome` will be immediately
+        be callled with `final_state=None`.
         Subclasses that want to handle this case should explicitly define what
         happens.
 
@@ -135,8 +140,9 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
         # If not overriden, the final_state should have type U_co.
         return cast(U_co, final_state)
 
-    def order(self,
-              *generators: icepool.OutcomeCountGenerator[T_contra]) -> Order:
+    def order(
+            self, *generators: icepool.OutcomeCountGenerator[T_contra,
+                                                             Any]) -> Order:
         """Optional function to determine the order in which `next_state()` will see outcomes.
 
         There is no expectation that a subclass be able to handle
@@ -164,7 +170,7 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
         return Order.Ascending
 
     def alignment(
-        self, *generators: icepool.OutcomeCountGenerator[T_contra]
+        self, *generators: icepool.OutcomeCountGenerator[T_contra, Any]
     ) -> Collection[T_contra]:
         """Optional method to specify an collection of outcomes that should always be given to `next_state()` even if they have zero count.
 
@@ -183,8 +189,9 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
         return ()
 
     def range_alignment(
-            self,
-            *generators: icepool.OutcomeCountGenerator[int]) -> Collection[int]:
+        self,
+        *generators: icepool.OutcomeCountGenerator[int,
+                                                   Any]) -> Collection[int]:
         """Example implementation of `alignment()` that produces consecutive `int` outcomes.
 
         There is no expectation that a subclass be able to handle
@@ -222,7 +229,8 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
         return {}
 
     def evaluate(
-        self, *generators: icepool.OutcomeCountGenerator[T_contra] |
+        self, *generators: icepool.OutcomeCountGenerator[T_contra,
+                                                         tuple[Q_contra, ...]] |
         Mapping[T_contra, int] | Sequence
     ) -> 'icepool.Die[U_co]':
         """Evaluates generator(s).
@@ -243,10 +251,9 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
             A `Die` representing the distribution of the final score.
         """
 
-        # Convert non-`Pool` arguments to `Pool`.
+        # Convert arguments to generators.
         converted_generators = tuple(
-            generator if isinstance(generator, icepool.OutcomeCountGenerator
-                                   ) else icepool.Pool(generator)
+            icepool.implicit_convert_to_generator(generator)
             for generator in generators)
 
         if not all(generator._is_resolvable()
@@ -267,8 +274,7 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
             if outcome is None:
                 raise TypeError(
                     "None is not a valid final outcome. "
-                    "This may have resulted from supplying an empty generator to OutcomeCountEvaluator. "
-                    "If so, refrain from using empty generators, or override OutcomeCountEvaluator.final_outcome() to handle this case."
+                    "This may have been a result of not supplying any generator with an outcome."
                 )
             if outcome is not icepool.Reroll:
                 final_outcomes.append(outcome)
@@ -279,7 +285,7 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
     __call__ = evaluate
 
     def _select_algorithm(
-        self, *generators: icepool.OutcomeCountGenerator[T_contra]
+        self, *generators: icepool.OutcomeCountGenerator[T_contra, Any]
     ) -> tuple[Callable, Order]:
         """Selects an algorithm and iteration order.
 
@@ -322,8 +328,8 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
             return self._eval_internal_iterative, eval_order
 
     def _eval_internal(
-        self, order: int, alignment: Alignment,
-        generators: tuple[icepool.OutcomeCountGenerator[T_contra], ...]
+        self, order: int, alignment: Alignment[T_contra],
+        generators: tuple[icepool.OutcomeCountGenerator[T_contra, Any], ...]
     ) -> Mapping[Any, int]:
         """Internal algorithm for iterating in the more-preferred order,
         i.e. giving outcomes to `next_state()` from wide to narrow.
@@ -368,8 +374,8 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
         return result
 
     def _eval_internal_iterative(
-        self, order: int, alignment: Alignment,
-        generators: tuple[icepool.OutcomeCountGenerator[T_contra], ...]
+        self, order: int, alignment: Alignment[T_contra],
+        generators: tuple[icepool.OutcomeCountGenerator[T_contra, Any], ...]
     ) -> Mapping[Any, int]:
         """Internal algorithm for iterating in the less-preferred order,
         i.e. giving outcomes to `next_state()` from narrow to wide.
@@ -406,9 +412,10 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
 
     @staticmethod
     def _pop_generators(
-        side: int, alignment: Alignment,
-        generators: tuple[icepool.OutcomeCountGenerator[T_contra], ...]
-    ) -> tuple[Any, Alignment, tuple['icepool.NextOutcomeCountGenerator', ...]]:
+        side: int, alignment: Alignment[T_contra],
+        generators: tuple[icepool.OutcomeCountGenerator[T_contra, Any], ...]
+    ) -> tuple[Any, Alignment[T_contra], tuple[
+            'icepool.NextOutcomeCountGenerator', ...]]:
         """Pops a single outcome from the generators.
 
         Returns:
@@ -436,7 +443,7 @@ class OutcomeCountEvaluator(ABC, Generic[T_contra, U_co]):
             return outcome, next_alignment, tuple(
                 generator._generate_min(outcome) for generator in generators)
 
-    def sample(self, *generators: icepool.OutcomeCountGenerator[T_contra] |
+    def sample(self, *generators: icepool.OutcomeCountGenerator[T_contra, Any] |
                Mapping[T_contra, int] | Sequence[T_contra]):
         """EXPERIMENTAL: Samples one result from the generator(s) and evaluates the result."""
         # Convert non-`Pool` arguments to `Pool`.
